@@ -460,6 +460,11 @@ class PageAdminSupport:
             BLATHER('creating catalog for wiki',self.folder().getId())
             self.setupCatalog()
 
+    def fixAllPagesEncoding(self, REQUEST=None):
+        """Fix character encoding throughout the wiki."""
+        for p in self.pageObjects(): p.fixEncoding(p)
+        if REQUEST: REQUEST.RESPONSE.redirect(REQUEST['URL1'])
+
     def fixEncoding(self, FROM='iso8859-1', TO='utf-8', REQUEST=None):
         """
         Try to fix any character encoding problems in this page's name or text.
@@ -487,10 +492,6 @@ class PageAdminSupport:
             return True
         if REQUEST: REQUEST.RESPONSE.redirect(self.pageUrl())
 
-    def fixAllPagesEncoding(self, REQUEST=None):
-        for p in self.pageObjects(): fixEncoding(p)
-        if REQUEST: REQUEST.RESPONSE.redirect(REQUEST['URL1'])
-
 InitializeClass(PageAdminSupport)
 
 
