@@ -149,7 +149,7 @@ class MailIn:
         # ..Type Error - configured ezmlm to provide beenthere instead (?)
         self.xbeenthere = self.msg.get('X-BeenThere')
 
-        # raises an exception if there's no text part
+        # the mailin body will be the message's first text/plain part
         try:
             firstplaintextpart = typed_subpart_iterator(self.msg,
                                                         'text',
@@ -159,6 +159,18 @@ class MailIn:
             payloadutf8 = payload.decode(content_encoding).encode('utf-8')
         except StopIteration:
             payloadutf8 = ''
+        # also, if there is a text/x-darcs-patch part, append that
+        try:
+            firstdarcspatchpart = typed_subpart_iterator(self.msg,
+                                                        'text',
+                                                        'x-darcs-patch').next()
+            payload = firstdarcspatchpart.get_payload(decode=1)
+            content_encoding = self.msg.get_content_charset('ascii')
+            payloadutf8 += '\n\n'
+            payloadutf8 += payload.decode(content_encoding).encode('utf-8')
+        except StopIteration:
+            payloadutf8 += ''
+
         self.body = self.cleanupBody(payloadutf8)
         
     def isJunk(self):
@@ -269,13 +281,9 @@ class MailIn:
         """
         # strip trailing newlines that seem to get added in transit
         body = re.sub(r'(?s)\n+$',r'\n',body)
+        body = stripBottomQuoted(body)
         # strip Bob's signature
         body = self.stripSignature(body)
-        # strip TBC (typical bloody citations)
-        #body = re.sub(
-        #    r'(?si)----- ?message d\'origine.*',r'',body)
-        #body = re.sub(
-        #    r'(?si)----- ?original message.*',r'',body)
         return body
 
     def stripSignature(self,body):
@@ -498,6 +506,11 @@ class MailIn:
 #                        break
 #        return folder
 
+def stripBottomQuoted(body):
+    origmsg = '(?:Original Message|message d\'origine)' # XXX i18n.. ?
+    body = re.sub(r'(?smi)^-+%s-+$.*' % origmsg, '', body)
+    return body
+
 
 def mailin(self, msg):
     """
