@@ -58,16 +58,22 @@ class Tests(ZwikiTestCase):
         sl._resetSubscribers()
         self.assertEquals(sl.subscriberList(),[])
         self.assertEquals(sl.subscriberCount(),0)
+        self.assertEquals(sl.pageSubscriberCount(),0)
+        self.assertEquals(sl.wikiSubscriberCount(),0)
         sl.subscribe('1@test.com')
         self.assertEquals(sl.subscriberList(),['1@test.com'])
         # check issue #161
         self.assertEquals(MockZWikiPage.subscriber_list,[]) 
         self.assertEquals(sl.subscriberCount(),1)
+        self.assertEquals(sl.pageSubscriberCount(),1)
+        self.assertEquals(sl.wikiSubscriberCount(),0)
         self.assert_(sl.isSubscriber('1@test.com'))
         self.assert_(not sl.isSubscriber('2@test.com'))
         sl.subscribe('2@test.com')
         self.assertEquals(sl.subscriberList(),['1@test.com', '2@test.com'])
         self.assertEquals(sl.subscriberCount(),2)
+        self.assertEquals(sl.pageSubscriberCount(),2)
+        self.assertEquals(sl.wikiSubscriberCount(),0)
         self.assert_(sl.isSubscriber('2@test.com'))
         sl.subscribe('1@test.com')
         self.assertEquals(sl.subscriberList(),['1@test.com', '2@test.com'])
