@@ -18,14 +18,18 @@ try: # zope 2.7
 except ImportError:
     DateTimeSyntaxError = DateTime.SyntaxError
 try:
-    v = open(os.path.join(SOFTWARE_HOME,'version.txt')).read()
+    path = os.path.join(SOFTWARE_HOME,'Zope2','version.txt') # >=2.9
+    if not os.path.exists(path):
+        path = os.path.join(SOFTWARE_HOME,'version.txt') # <= 2.8
+    v = open(path).read()
     m = re.match(r'(?i)zope\s*([0-9]+)\.([0-9]+)\.([0-9]+)',v)
     ZOPEVERSION = (int(m.group(1)),int(m.group(2)),int(m.group(3)))
-except:
+except (IOError, AttributeError): # AttributeError: regex didn't match
     ZOPEVERSION = (9,9,9) # (cvs)
 
 from Products.ZWiki import __version__
-from Defaults import PREFER_USERNAME_COOKIE, PAGE_METADATA, BORING_PAGES
+from Defaults import PREFER_USERNAME_COOKIE, PAGE_METADATA, BORING_PAGES, \
+                     PAGE_METATYPE
 import Permissions
 from I18n import _
 
@@ -175,25 +179,32 @@ class PageUtils:
         It should mimic the search strategy of SearchPage, but that
         depends on catalog configuration and it currently doesn't do a
         very good job, so the excerpts and highlights can be misleading.
+
+        We jump through some hoops to ensure that excerpts have valid
+        encoding. This is to avoid breaking searchwiki.pt, which needs
+        to convert search results to unicode for newer zopes. (#1389)
         """
         text = text or self.text()
         string = re.sub(r'\*','',expr)
+        try: text, string = tounicode(text), tounicode(string)
+        except UnicodeDecodeError: return ''
         m = re.search(r'(?i)'+re.escape(string),text)
         if m and string:
             middle = (m.start()+m.end())/2
             exstart = max(middle-size/2-1,0)
             exend = min(middle+size/2+1,len(text))
-            excerpt = html_quote(text[exstart:exend])
-            if highlight:
-                excerpt = re.sub(
-                    r'(?i)'+re.escape(html_quote(string)),
-                    #'<span class="hit">%s</span>' % html_quote(m.group()),
-                    # XXX temp
-                    '<span class="hit" style="background-color:yellow;font-weight:bold;">%s</span>' % html_quote(m.group()),
-                    excerpt)
-            return excerpt
+            excerpt = html_quote(toencoded(text[exstart:exend]))
         else:
-            return html_quote(text[:size])
+            excerpt = html_quote(toencoded(text[:size]))
+        if highlight:
+            highlightstring = m and m.group() or string
+            if highlightstring:
+                excerpt = re.sub(
+                    r'(?i)'+re.escape(html_quote(toencoded(string))),
+                    '<span class="hit" style="background-color:yellow;font-weight:bold;">%s</span>' % html_quote(toencoded(highlightstring)),
+                    excerpt)
+        excerpt = toencoded(excerpt)
+        return excerpt
 
     def metadataFor(self,page):
         """
@@ -206,7 +217,12 @@ class PageUtils:
 
         Warning: fields such as the parents list may be
         copies-by-reference, and should not be mutated.
+
+        Since we're ensuring that we always have a catalog now (since 0.60),
+        this thing should not be needed any more. XXX remove this method?
         """
+        if getattr(page, 'meta_type', None)!=PAGE_METATYPE:
+            raise TypeError(str(page)+' is not a '+PAGE_METATYPE)
         class PageBrain(SimpleItem): # XXX why a SimpleItem ?
             def __init__(self,obj): self._obj = obj
             def getObject(self): return self._obj
@@ -356,10 +372,11 @@ class PageUtils:
     def changesUrl(self):
         return self.urlForDtmlPageOrMethod('RecentChanges','recentchanges')
 
-    security.declareProtected(Permissions.View, 'discussionUrl')
-    def discussionUrl(self):
-        p = self.pageWithName('GeneralDiscussion')
-        return (p and p.pageUrl()) or ''
+    security.declareProtected(Permissions.View, 'feedUrl')
+    def feedUrl(self):
+        return self.defaultPageUrl() + '/pages_rss'
+
+    discussionUrl = defaultPageUrl
 
     security.declareProtected(Permissions.View, 'indexUrl')
     def indexUrl(self):
@@ -371,7 +388,12 @@ class PageUtils:
 
     security.declareProtected(Permissions.View, 'preferencesUrl')
     def preferencesUrl(self):
-        return self.urlForDtmlPageOrMethod('UserOptions','useroptions')
+        """
+        Produce the link for the "options" page, also transmitting
+        the current page URL to redirect back to.
+        """
+        prefurl = self.urlForDtmlPageOrMethod('UserOptions','useroptions')
+        return prefurl + '?redirectURL='+quote(self.pageUrl())
 
     security.declareProtected(Permissions.View, 'helpUrl')
     def helpUrl(self):
@@ -534,23 +556,33 @@ class PageUtils:
 
     def talsafe(self,s):
         """
-        Sanitize a string for use with TAL's structure keyword.
+        Make a string safe for use with TAL's structure keyword.
 
         Zope versions before 2.10 expect such data to be an ordinary
         string.  Zope 2.10 expects it to be unicode, or to at least be
         convertible to unicode using the default encoding.  We can't
         guarantee the latter, so convert to unicode preemptively assuming
-        our standard encoding in that case.  (cf issue #1330)
+        our standard encoding.  (cf issue #1330)
 
         This is idempotent, safe to call repeatedly.
         """ 
-        if ZOPEVERSION < (2,10) or type(s) is UnicodeType:
-            return s
-        else:
-            return unicode(s, 'utf-8')
+        if ZOPEVERSION < (2,10): return s
+        else:                    return tounicode(s)
         
 InitializeClass(PageUtils)
 
+def toencoded(s,enc='utf8'):
+    """Safely convert a unicode string to an encoded ordinary string.
+    UTF8 is used by default."""
+    if isunicode(s): return s.encode(enc)
+    else:            return s
+
+def tounicode(s,enc='utf8'):
+    """Safely convert an encoded ordinary string to a unicode string.
+    UTF8 is used by default."""
+    if isunicode(s): return s
+    else:            return s.decode(enc)
+
 
 # generic utilities
 
@@ -857,3 +889,15 @@ if not safe_hasattr(__builtins__,'sorted'):
         return L
 else:
     sorted = sorted
+
+# unique values of a list
+def nub(l):
+    u = []
+    for v in l:
+        if not v in u: u.append(v)
+    return u
+        
+isnumeric = lambda v:isinstance(v,IntType) or isinstance(v,FloatType) or isinstance(v,LongType)
+isfloat   = lambda v:isinstance(v,FloatType)
+isstring  = lambda v:isinstance(v,StringType)
+isunicode = lambda v:isinstance(v,UnicodeType)
