@@ -168,10 +168,10 @@ def isPageTemplate(obj):
 
 def isDtmlMethod(obj):
     return getattr(obj,'meta_type',None) in (
-        'DTML Method', 
+        'DTML Method',
         'Filesystem DTML Method',
         'DTML Method (File)',
-        'DTML Document', 
+        'DTML Document',
         'Filesystem DTML Document',
         'DTML Document (File)',
         )
@@ -206,6 +206,7 @@ for s in os.listdir(abszwikipath('skins')):
         'backlinks',
         'contentspage',
         'denied',
+        'genericerror',
         'diffform',
         'editform',
         'history',
@@ -226,6 +227,7 @@ for s in os.listdir(abszwikipath('skins')):
         'pageheader',
         'pagemanagementform',
         'siteheader',
+        'sitefooter',
         'testtemplate',
         'badtemplate',
         ]:
@@ -290,7 +292,7 @@ MACROS['wikilinks']   = nullmacro
 
 
 class SkinViews:
-    """ 
+    """
     This mixin defines the main Zwiki UI views as methods.
 
     These view methods usually just call a built-in template of the same
@@ -380,6 +382,13 @@ class SkinViews:
         """
         return self.getSkinTemplate('denied')(self,REQUEST,reason=reason)
 
+    security.declarePublic('genericerror')
+    def genericerror(self, shorttitle='', messagetitle='', messages=[], REQUEST=None):
+        """
+        Render a generic error message (template-customizable).
+        """
+        return self.getSkinTemplate('genericerror')(self,REQUEST,shorttitle=shorttitle, messagetitle=messagetitle, messages=messages)
+
     security.declareProtected(Permissions.View, 'diffform')
     def diffform(self, rev, difftext, bodytext, REQUEST=None):
         """
@@ -449,7 +458,7 @@ class SkinViews:
         if not self.checkSufficientId(REQUEST):
             return self.denied(
                 _("Sorry, this wiki doesn't allow anonymous edits. Please configure a username in options first."))
-        
+
         if ((not page or page == self.pageName()) and
             safe_hasattr(self,'wl_isLocked') and self.wl_isLocked()):
             return self.davLockDialog()
@@ -473,7 +482,7 @@ class SkinViews:
         # XXX can we simplify this/make dtml more version independent ?
         # NB 'id' and 'oldid' are no longer used, but provide them for
         # backwards compatibility with old templates
-            
+
         return self.getSkinTemplate('editform')(self,REQUEST,
                                                 page=page,
                                                 text=text,
@@ -507,60 +516,8 @@ class SkinViews:
         """
         return self.getSkinTemplate('helppage')(self,REQUEST)
 
-    security.declareProtected(Permissions.View, 'showAccessKeys')
-    def showAccessKeys(self):
-        """
-        Show the access keys supported by the built-in skins.
-        """
-        return _("""
-        Access keys can be accessed in mozilla-based browsers by pressing alt-<key>
-        IE users: must also press enter
-        Mac users: command-<key>
-        Opera users: shift-escape-<key>
-        These won't work here, back up to the previous page to try them out.
+    showAccessKeys = helppage #backwards compatibility
 
-        0    show these access key assignments
-
-        wiki functions:
-        f    show front page
-        c    show wiki contents
-        r    show wiki recent changes
-             show discussion page
-        t    show issue tracker
-        i    show wiki index
-        o    show wiki options (preferences)
-        h    show help page
-        s    go to search field
-        
-        page functions:
-        +    (in a plone/cmf site with skin switching set up) use zwiki's plone/cmf skin
-        -    (in a plone/cmf site with skin switching set up) use zwiki's standard skin
-        v    view page
-        m    mail subscription
-        b    show backlinks (links to this page)
-        d    show diffs (page edit history)
-        y    show full history (in ZMI)
-        e    edit this page                       
-        x    edit with an external editor
-             print this page (and subtopics)
-        q    view page source (quick-view)
-             wipe and regenerate this page's render cache
-             go to subtopics
-             go to comments (messages)
-             go to page author's home page, if possible
-        n    next page
-        p    previous page
-        u    up to parent page
-        
-        in edit form:
-        s    save changes
-        p    preview
-        
-        when viewing diffs:
-        n    next edit
-        p    previous edit
-        """)
-    
     security.declareProtected(Permissions.View, 'stylesheet')
     def stylesheet(self, REQUEST=None):
         """
@@ -620,12 +577,12 @@ class SkinUtils:
     #    XXX should be going away soon. Old comment: the wikipage template
     #    is usually applied by __call__ -> addSkinTo, but this method is
     #    provided so you can configure it as the"view" action
-    #    in portal_types -> Wiki Page -> actions and get use Zwiki's standard 
+    #    in portal_types -> Wiki Page -> actions and get use Zwiki's standard
     #    skin inside a CMF/Plone site.
     #    """
     #    return self.render(REQUEST=REQUEST,RESPONSE=RESPONSE)
     #wikipage_view = wikipage
-    
+
     # backwards compatibility - some old templates expect
     # wikipage_template().macros or wikipage_macros something something
     def wikipage_template(self, REQUEST=None): return self
@@ -693,7 +650,7 @@ class SkinUtils:
         """
         # != ignores any acquisition wrapper
         return self.getSkinTemplate(name) != TEMPLATES['badtemplate']
-        
+
     security.declareProtected(Permissions.View, 'addSkinTo')
     def addSkinTo(self,body,**kw):
         """
@@ -776,7 +733,7 @@ class SkinSwitchingUtils:
         Ie, are we using the plone display mode of zwiki's standard skin.
         """
         return (self.inCMF() and self.displayMode()=='plone')
-        
+
     security.declareProtected(Permissions.View, 'setCMFSkin')
     def setCMFSkin(self,REQUEST,skin):
         """
