@@ -9,41 +9,6 @@ Full credits are at http://zwiki.org/ZwikiContributors .
 
 This product is available under the GNU GPL.  All rights reserved, all
 disclaimers apply, etc.
-
-
-STYLE NOTES
-    
-imports
-
- are usually in three groups: python, then zope, then zwiki imports
-
-docstrings
-
- "The first line should always be a short, concise summary of the
- object's purpose.  For brevity, it should not explicitly state the
- object's name or type, since these are available by other means (except
- if the name happens to be a verb describing a function's operation).
- This line should begin with a capital letter and end with a period.
-
- If there are more lines in the documentation string, the second line
- should be blank, visually separating the summary from the rest of the
- description.  The following lines should be one or more paragraphs
- describing the object's calling conventions, its side effects, etc.
-
- Data attributes override method attributes with the same name; to
- avoid accidental name conflicts, which may cause hard-to-find bugs in
- large programs, it is wise to use some kind of convention 
- [such as] verbs for methods and nouns for data attributes."
-
-method visibility
-
- naming with _ for privacy obscures the code, and so do excessive
- security declarations. Omitting docstrings or documenting with comments
- are not good either. Where a docstring is needed, I'm considering
- putting it above the method name to indicate private methods, which
- avoids these problems and makes it easy to change your mind.
- No, too weird.
-
 """
 
 from __future__ import nested_scopes
@@ -141,14 +106,16 @@ class ZWikiPage(
     security.declareProtected(Permissions.Edit, 'manage_upload')
     security.declareProtected(Permissions.FTP, 'manage_FTPstat') # needed
     security.declareProtected(Permissions.FTP, 'manage_FTPlist') # ?
+
+    def checkPermission(self, permission, object):
+        return getSecurityManager().checkPermission(permission,object)
+
     # perms need at least one declaration (in this file ?) to be recognized
     # this is dumb indeed.. need tests to figure out the rules of this game
     security.declareProtected(Permissions.ChangeType, 'dummy')
     def dummy(self): pass
     security.declareProtected(Permissions.Reparent, 'dummy2')
     def dummy2(self): pass
-    def checkPermission(self, permission, object):
-        return getSecurityManager().checkPermission(permission,object)
 
     # properties visible in the ZMI
     _properties=(
@@ -189,9 +156,12 @@ class ZWikiPage(
     # behaviour. It will return the old id string when called, which
     # should keep existing catalogs working.
     page_type = DEFAULT_PAGETYPE()
+    # pre-rendered text cache
+    _prerendered = ''   
 
     # XXX page_type's are separate instances - use class or singleton instance ?
     def setPageType(self,id=None): self.page_type = self.lookupPageType(id)()
+
     security.declarePublic('pageType') # useful for troubleshooting
     def pageType(self):
         """Return this page's page type object."""
@@ -205,18 +175,19 @@ class ZWikiPage(
         elif not safe_hasattr(self.page_type,'render'):
             self.setPageType(DEFAULT_PAGETYPE)
         return self.page_type
+
     def lookupPageType(self,id=None):
         """Return the page type object with this id (or the default)"""
         match = filter(lambda x:x._id==id,PAGETYPES)
         return (match and match[0]) or DEFAULT_PAGETYPE
+
     security.declarePublic('pageTypeId') # useful for troubleshooting
     def pageTypeId(self):
         """Return the short id for this page's page type."""
         return self.pageType().id()
 
-    # pre-rendered text cache
-    _prerendered = ''   
     def setPreRendered(self,t): self._prerendered = t
+
     def preRendered(self):
         # cope with non-existing or None attribute on old instances - needed ?
         return getattr(self,'_prerendered','') or ''
@@ -250,13 +221,12 @@ class ZWikiPage(
     security.declareProtected(Permissions.View, '__call__')
     def __call__(self, client=None, REQUEST={}, RESPONSE=None, **kw):
         """
-        Render this zwiki page, also upgrading it on the fly if needed.
+        Render this zwiki page, or, return a cache-friendly 304 response
+        if it seems appropriate. Also upgrade it on the fly if needed.
         """
-        if self.handle_modified_headers(REQUEST=REQUEST):
-            return '' # return a 304 response with no content
         if AUTO_UPGRADE: self.upgrade(REQUEST)
-        rendered = self.render(client,REQUEST,RESPONSE,**kw)
-        return rendered
+        if self.handle_modified_headers(REQUEST=REQUEST): return ''
+        else: return self.render(client,REQUEST,RESPONSE,**kw)
 
     def render(self, client=None, REQUEST={}, RESPONSE=None, **kw):
         """
@@ -286,6 +256,7 @@ class ZWikiPage(
         if clear_cache: self.clearCache()
         self.setPreRendered(self.pageType().preRender(self))
 
+    security.declarePublic('renderText')
     def renderText(self, text, type, **kw):
         """
         Render some source text according to the specified page type.
@@ -377,7 +348,7 @@ class ZWikiPage(
         """
         return (self.hasDynamicContent() and
                 self.dtmlAllowed() and
-                (re.search(r'(?i)(<dtml-var["\s]+|&dtml-)subtopics',
+                (re.search(r'(?i)(<dtml-var[^>]+subtopics|&dtml-subtopics)',
                            self.read()) is not None))
     
     security.declareProtected(Permissions.View, 'supportsStx')
@@ -443,15 +414,17 @@ class ZWikiPage(
         then if a 304 is called for this method returns True and
         the calling method should give no content to the browser.
         """
-        RESPONSE=REQUEST.RESPONSE
+        RESPONSE = getattr(REQUEST,'RESPONSE',None)
+        if not RESPONSE:return False
         # do we handle things at all?
         if not getattr(self, 'conditional_http_get', CONDITIONAL_HTTP_GET):
             return False
         # admins can specify a list of property names that make us ignore
         # "Conditional HTTP Get" processing if they are set
         # especially useful for ignoring pages with allow_dtml
-        ignore = getattr(self, 'conditional_http_get_ignore', \
-                                        CONDITIONAL_HTTP_GET_IGNORE)
+        ignore = getattr(
+            self, 'conditional_http_get_ignore', CONDITIONAL_HTTP_GET_IGNORE)
+                         
         for ignore_property in ignore:
             if getattr(self, ignore_property, False): return False
         if last_mod == None:
@@ -590,10 +563,8 @@ class ZWikiPage(
         An alternative to the more usual markLinksIn + renderMarkedLinksIn.
         """
         t = self.applyWikiLinkLineEscapesIn(text)
-        # ken's clever thunk_substituter helps provide context (or something)
-        return re.sub(anywikilinkexpr,
-                      thunk_substituter(self.renderLink, t, 1),
-                      t)
+        # ken's clever thunk_substituter helps keep track of state
+        return re.sub(anywikilinkexpr, thunk_substituter(self.renderLink, t), t)
 
     wikilink = renderLinksIn # convenience alias
 
@@ -607,8 +578,7 @@ class ZWikiPage(
             lambda m:re.sub(wikilink, r'!\1', m.group(1)),
             text)
         
-    def renderLink(self,link,allowed=0,state=None,text='',
-                   link_title=None,access_key=None):
+    def renderLink(self,link,state=None,text='',link_title=None,access_key=None):
         """
         Render various kinds of hyperlink, based on page and wiki state.
 
@@ -765,17 +735,6 @@ class ZWikiPage(
                 quote(self.id()),
                 quote(page),
                 _("create this page")))
-                  
-        # subwiki support: or does a matching page exist in the parent folder ?
-        # XXX this is dumber than the above; doesn't handle i18n
-        # characters, freeform names
-        #if (hasattr(self.folder(),'aq_parent') and
-        #      hasattr(self.folder().aq_parent, page) and
-        #      self.isZwikiPage(getattr(self.folder().aq_parent,page))): #XXX poor caching
-        #    return '<a href="%s/../%s" title="%s">../%s</a>'\
-        #           % (self.wiki_url(),quote(page),_("page in parent wiki"),
-        #              self.formatWikiname(linkorig))
-
 
     def renderInterwikiLink(self, link):
         """
@@ -816,13 +775,8 @@ class ZWikiPage(
         """
         Return pagename with spaces inserted if it's a WikiName, or unchanged.
 
-        Tries to be conformant with the wikiname regexp wrt. i18n, etc.
+        Uses the wikiname regexp to follow localised capitalisation.
         """
-        #spaced = pagename[0]
-        #for c in pagename[1:]:
-        #    if c in string.uppercase: spaced += ' '
-        #    spaced += c
-        #return spaced
         if re.match('^%s$' % wikiname, pagename):
             words = [x[0] for x in re.findall(wikinamewords,pagename)]
             return ' '.join(words)
@@ -840,9 +794,9 @@ class ZWikiPage(
         List the unique links occurring on this page - useful for cataloging.
 
         Includes urls & interwiki links but not structured text links.
-        Extracts the marked links from prerendered data.  Does not
-        generate this if missing - too expensive when cataloging ?
+        Extracts the marked links from prerendered data.
         """
+        # don't generate this if missing - too expensive when cataloging ?
         #if not self.preRendered(): self.preRender()
         links = []
         for l in re.findall(markedwikilinkexpr,self.preRendered()):
@@ -1054,76 +1008,23 @@ class ZWikiPage(
         """
         Look up metadata (brains) for some or all pages in this wiki.
 
-        optimisation: prior to 0.22 this returned the actual page objects,
-        but to help with caching efficiency it now uses the catalog, if
-        possible.  The page metadata objects are catalog brains (search
-        results) containing the catalog's metadata, or workalikes
-        containing a limited number of fields and getObject().
+        This is a wrapper for searching the wiki's catalog. It filters
+        out results for other folders, to allow us to share a catalog
+        (eg within Plone).
 
-        Warning: fields such as the parents list may be
-        copies-by-reference, and should not be mutated.
-
-        Any keyword arguments will be passed through to the catalog, for
-        refining the search, sorting etc. When there is no catalog, only
-        these arguments are supported: id, Title, text, isIssue, and they
-        do case insensitive partial matching.  With no arguments, all
-        pages in the wiki are returned.
-
-        With a partial catalog, ie a catalog which does not include all
-        the metadata Zwiki expects, we'll get the missing fields from the
-        zodb and add them to the catalog brains. In this case the
-        catalog's caching advantage is lost.
-
-        ensureCompleteMetadata may return None, indicating a stale catalog
-        entry; we filter those out.
-
-        Different catalog configurations screw up our title and text
-        searches somewhat. For the standard search form, we want: case
-        insensitive, partial matching in page names and page text.
-        
+        Up to 0.60 it used to fall back to a (less cache-friendly)
+        zodb search when there was no catalog, and this turns out to
+        be bad when viewing old revisions, which don't have a catalog,
+        so we no longer do that.
         """
-        if self.hasAllCatalogFields():
-            wikipath = self.wikiPath()
-            def inthiswiki(b):
-                p = b.getPath()
-                return p[:p.rfind('/')] == wikipath
-            return [b for b in
-                    self.searchCatalog(meta_type=self.meta_type,path=wikipath,**kw)
-                    if inthiswiki(b)]
-
-        else:
-            results = []
-            for p in self.pageObjects(): results.append(self.metadataFor(p))
-            # emulate (some) catalog arguments in a rudimentary way
-            # these are all partial matching, case insensitive
-            if kw:
-                for arg in kw.keys():
-                    value = kw[arg]
-                    # catalog may use wildcards, but we won't
-                    def stripWildCardsFrom(s):
-                        try: return s.replace('*','')
-                        except AttributeError: return s
-                    value = stripWildCardsFrom(value)
-                    if arg == 'text':
-                        results = filter(
-                            lambda x:find(x.getObject().text().lower(),
-                                          value.lower()) != -1,
-                            results)
-                    if arg == 'id':
-                        results = filter(
-                            lambda x:find(x.id.lower(),value.lower()) != -1,
-                            results)
-                    if arg == 'Title':
-                        results = filter(
-                            lambda x:find(x.Title.lower(),value.lower()) != -1,
-                            results)
-                    if arg == 'isIssue':
-                        results = filter(
-                            lambda x:self.isIssue(x.Title) == value,
-                            results)
-                    #if arg == 'sort_order':
-                    #if arg == 'sort_on':
-            return results
+        if not self.hasAllCatalogFields(): return []
+        wikipath = self.wikiPath()
+        def inthiswiki(b):
+            p = b.getPath()
+            return p[:p.rfind('/')] == wikipath
+        return [b for b in
+                self.searchCatalog(meta_type=self.meta_type,path=wikipath,**kw)
+                if inthiswiki(b)]
 
     security.declareProtected(Permissions.View, 'pageCount')
     def pageCount(self):
@@ -1418,20 +1319,17 @@ InitializeClass(ZWikiPage)
 
 # rendering helper functions
 
-def thunk_substituter(func, text, allowed):
+def thunk_substituter(func, text):
     """Return a function which takes one arg and passes it with other args
     to passed-in func.
 
-    thunk_substituter passes in the value of it's parameter, 'allowed', and a
-    dictionary {'lastend': int, 'inpre': bool, 'intag': bool}.
-
-    This is for use in a re.sub situation, to get the 'allowed' parameter and
-    the state dict into the callback.
+    thunk_substituter passes in a state dictionary: {'lastend': int,
+    'inpre': bool, 'intag': bool}.  This is for use in a re.sub
+    situation, to get the state into the callback.
 
     (The technical term really is "thunk".  Honest.-)"""
     state = {'lastend':0,'inpre':0,'incode':0,'intag':0,'inanchor':0}
-    return lambda arg, func=func, allowed=allowed, text=text, state=state: (
-        func(arg, allowed, state, text))
+    return lambda arg, func=func, text=text, state=state: func(arg,state,text)
 
 def within_literal(upto, after, state, text,
                    rfind=rfind, lower=lower):
