@@ -3,7 +3,7 @@
 __doc__="""
 ZWiki product
 """
-__version__='0.60.0'
+__version__='0.61.0'
 
 import re, os.path, string, urllib
 
@@ -289,7 +289,7 @@ def manage_addWiki(self, new_id, new_title='', wiki_type='basic',
                 REQUEST.RESPONSE.redirect(REQUEST['URL3']+'/'+new_id+'/')
             else:
                 try: u=self.DestinationURL()
-                except: u=REQUEST['URL1']
+                except AttributeError: u=REQUEST['URL1']
                 REQUEST.RESPONSE.redirect(u+'/manage_main?update_menu=1')
         else: # we're called programmatically through xx.manage_addProduct...
             return new_id
