@@ -23,6 +23,8 @@ class PageTypeHtml(PageTypeBaseHtml):
         else:
             t = page.preRendered()
         t = page.renderMarkedLinksIn(t)
+        if page.isIssue() and kw.get('show_issueproperties',1):
+            t = page.addIssueFormTo(t)
         t = page.renderMidsectionIn(t,**kw)
         t = page.addSkinTo(t,**kw)
         return t
