@@ -1,4 +1,5 @@
 from Products.ZWiki.testsupport import *
+from types import DictionaryType
 ZopeTestCase.installProduct('ZCatalog')
 ZopeTestCase.installProduct('ZWiki')
 
@@ -12,6 +13,7 @@ class Tests(ZwikiTestCase):
         ZwikiTestCase.afterSetUp(self)
         self.p.REQUEST.REMOTE_ADDR = '1'
         self.p.resetVotes()
+        self.p.ensureCatalog() # tests only, nowadays zwikis have catalogs
 
     def test_rating(self):
         p = self.p
@@ -33,3 +35,11 @@ class Tests(ZwikiTestCase):
         p.vote(1)
         self.assert_(p.voteCount() == 2)
 
+    def test_ensureVotesIsBtree(self):
+        p = self.p
+        p._votes = {'someoneelse':3} # fakeing an old voting module
+        p.ensureVotesIsBtree() # now "upgrading"
+        self.failIf(isinstance(p._votes, DictionaryType), \
+            'Not been converted to Btree!')
+        self.assert_(p.voteCount() == 1)
+        self.assertEqual(p._votes['someoneelse'], 3)
